import requests
import json
from bs4 import BeautifulSoup

class CFChecker:
    def __init__(
        self,
        baseURL="https://orders.cityfibre.com/ftth/availability-checker",
    ):
        self.baseURL = baseURL


    def get_address_data(self, postCode, houseNumber, strictAddress):
        address_list = requests.post(
            f'{self.baseURL}/postcode',
            data={"postal-code": postCode},
        )
        soup = BeautifulSoup(address_list.text, 'html.parser')
        addresses = soup.find_all('option')[1:]
        bestMatch = False
        matchLevel = 0

        for address in addresses:
            addressObj = json.loads(address['value'])
            if addressObj['addressString'].startswith(f'{houseNumber} '):
                return address['value']
            if not bestMatch:
                bestMatch = addressObj
            if "rfsStatus" in addressObj:
                if addressObj['rfsStatus'].startswith("RFS_"):
                    bestMatch = addressObj
                    matchLevel = 2
                elif addressObj['rfsStatus'].startswith("NOT_RFS_") and \
                    matchLevel < 1:
                    bestMatch = addressObj
                    matchLevel = 1
                    if addressObj['rfsStatus'] == "NOT_RFS_3":
                        matchLevel = 0

        if strictAddress or len(addresses) == 0:
            return '{}'

        bestMatch['looseMatch'] = True
        bestMatch['address'] = bestMatch['addressString']
        return json.dumps(bestMatch)


    def query_address(self, postCode, houseNumber, strictAddress=True):
        addressData = self.get_address_data(
            postCode,
            houseNumber,
            strictAddress
        )
        addressDataObj = json.loads(addressData)
        locFlags = []
        if "locFlags" in addressDataObj:
            locFlags = addressDataObj['locFlags'].split(" ")
        addressDataObj['locFlags'] = locFlags

        returnData = {
            "addressData": addressDataObj,
            'serviceable': False,
            'planned': False,
            'success': False,
            'providers': [],
        }

        if addressData != '{}' and "rfsStatus" not in addressDataObj:
            returnData['success'] = True
        elif "rfsStatus" in addressDataObj and \
            (addressDataObj['rfsStatus'].startswith("NOT_RFS_") or \
            addressDataObj['rfsStatus'] == "RFS_0"):
            returnData['planned'] = True
            returnData['success'] = True
            returnData['message'] = addressDataObj['rfsStatus']
        elif addressData != '{}':
            status_response = requests.post(
                f'{self.baseURL}/availability',
                data={"address": addressData},
            )
            soup = BeautifulSoup(status_response.text, 'html.parser')
            for provider in soup.find_all('input'):
                if provider.get("name", "") == "ispName":
                    returnData['providers'].append(provider['value'])
            if len(returnData['providers']) > 0:
                returnData['serviceable'] = True

            returnData['message'] = soup.find('h5').text.strip()
            returnData['planned'] = True
            returnData['success'] = True
        else:
            returnData['message'] = ('Could not find property from list for'
                f' house {houseNumber} at {postCode}')

        return CFResult(data=returnData)


# TODO: All the setting of values (basically all returnData.update() calls)
# should probably be handled in this class.
class CFResult:
    def __init__(self, data):
        self._data = data

    @property
    def data(self):
        return self._data

    @property
    def json(self):
        return json.dumps(self._data)

    @property
    def fttp(self):
        return self.data['serviceable']
