import requests
import json
import uuid
from .resultclass import BroadbandResult
from .addressmatch import UKBroadbandAddressMatcher

class CommunityFibreChecker:
    def __init__(
        self,
        APIAddress="https://api.communityfibre.co.uk",
        sessionID=str(uuid.uuid4()),
    ):
        self.APIAddress = APIAddress

        self.commonHeaders = {
            "user-id": "5be4c5577247450016ba8d7c",
            "access-token": "eyJhbGciOiJIUzI1NiIsInR5cCI6IkpXVCJ9.eyJ1c2VyTmFtZ"
                "SI6IndlYnNpdGUgIiwidXNlcklkIjoiNWJlNGM1NTc3MjQ3NDUwMDE2YmE4ZDd"
                "jIiwidXNlckFjY291bnRJZCI6IjViNTg4MDZhY2Q3OTRlMDE1ZjAzNDFjZCIsI"
                "nByb2ZpbGVJRCI6IjViNTg4MDZhY2Q3OTRlMDE1ZjAzNDFjZCIsInVzZXJHcm9"
                "1cHMiOlsiNWJlNGM2NmM3MjQ3NDUwMDE2YmE4ZDdkIl0sImlhdCI6MTU3MDk2N"
                "DA0MX0.YDtna26Oy7sNabGXY_JAeSNFwgjBFImNUulaJG_DMfg",
            "content-type": "application/json",
            "client-secret": "b58MrdyM4yhbyqIYAxkH",
        }

        self.sessionID = sessionID

    def query_address(self, postCode, houseNumber, strictAddress=True):
        searchQuery = {
            "filters": {
                "search": postCode,
                "searchKey": "pre:address=",
            },
            "sessionID": self.sessionID,
        }

        address_list = requests.post(
            f'{self.APIAddress}/address-service/search',
            data=json.dumps(searchQuery),
            headers=self.commonHeaders,
        )

        premiseCheckList = json.loads(address_list.text)['premisesFiltered']
        premiseCheckArray = []
        for thisAddress in premiseCheckList:
            premiseCheckArray.append({
                "addressLine": thisAddress['address'],
                "returnValue": thisAddress,
            })

        premise, strictMatched = UKBroadbandAddressMatcher(
            houseNumber,
            postCode,
            premiseCheckArray
        )
        if not strictMatched:
            if strictAddress:
                returnResult = BroadbandResult(
                    data={
                        "addressData": False,
                        'serviceable': False,
                        'success': False,
                        'fttp': False,
                    },
                )
                return returnResult
            else:
                premise['looseMatch'] = True

        serviceability = requests.post(
            f"{self.APIAddress}/address-service/{premise['sprn']}",
            headers=self.commonHeaders,
        )
        serviceabilityData = json.loads(serviceability.text)

        returnData = {
            "addressData": premise,
            "message": serviceabilityData,
            'serviceable': False,
            'planned': False,
            'success': False,
        }

        if serviceabilityData['accepting'] == "order":
            returnData.update({
                'serviceable': True,
                'planned': True,
                'success': True,
            })
        elif serviceabilityData['project_id'] and serviceabilityData['project_id'] > 0 or \
            serviceabilityData['accepting'] != "none":
            returnData.update({
                'planned': True,
                'success': True,
            })
        else:
            returnData.update({
                'success': True,
            })

        returnResult = BroadbandResult(
            data=returnData,
        )
        returnResult.fttp = returnData['serviceable']

        return returnResult
