import requests
import json
import base64
from .resultclass import BroadbandResult
from .addressmatch import UKBroadbandAddressMatcher

class GCChecker:
    def __init__(
        self,
        apiAddress="https://buy.gigaclear.com/api",
        apiKey="w7QvLfdyfPUgqs5bPOhv",
    ):
        self.apiAddress = apiAddress

        apiKey = apiKey.encode('ascii')
        apiKey = base64.b64encode(apiKey)
        self.apiKey = apiKey.decode('ascii')


    def query_address(self, postCode, houseNumber, strictAddress=True):
        returnData = {
            'serviceable': False,
            'planned': False,
            'success': False,
        }

        headers = {'x-api-key': self.apiKey}

        address_list = requests.get(
            f'{self.apiAddress}/obj/address/{postCode}',
            headers=headers,
        )
        if address_list.status_code == 404:
            returnData['success'] = True
        else:
            premiseCheckList = json.loads(address_list.text)['addresses']
            premiseCheckArray = []
            for thisAddress in premiseCheckList:
                premiseCheckArray.append({
                    "addressLine": thisAddress['address'],
                    "returnValue": thisAddress,
                })

            premise, strictMatched = UKBroadbandAddressMatcher(
                houseNumber,
                postCode,
                premiseCheckArray
            )
            if not strictMatched:
                if strictAddress:
                    returnResult = BroadbandResult(
                        data={
                            "addressData": False,
                            'serviceable': False,
                            'success': False,
                            'fttp': False,
                        },
                    )
                    return returnResult
                else:
                    premise['looseMatch'] = True

            returnData['addressData'] = premise

            serviceability = requests.get(
                f'{self.apiAddress}/obj/property/{premise["property_id"]}',
                headers=headers,
            )

            serviceabilityData = json.loads(serviceability.text)
            returnData['message'] = serviceabilityData
            if serviceability.status_code == 200:
                if serviceabilityData['rfs']:
                    returnData.update({
                        'serviceable': True,
                        'planned': True,
                        'success': True,
                    })
                elif serviceabilityData['pre_order'] or \
                    serviceabilityData['estimated_completion']:
                    returnData.update({
                        'planned': True,
                        'success': True,
                    })

        returnResult = BroadbandResult(
            data=returnData,
        )
        returnResult.fttp = returnData['serviceable']

        return returnResult
