import requests
import json
from .resultclass import BroadbandResult
from .swishfibre import SwichFibreChecker

class GNetworkChecker:
    def __init__(
        self,
        APIAddress="https://www.g.network/api/property",
    ):
        self.APIAddress = APIAddress


    def query_address(self, postCode, houseNumber, strictAddress=True):
        postCode = ''.join(ch for ch in postCode if ch.isalnum())

        # G.Network has harsh restrictions for lookups, we can use Swish's for
        # the moment until we improve the UI logic to support caching IDs
        swishChecker = SwichFibreChecker().match_uprn(postCode, houseNumber)
        return BroadbandResult(
            data=self.lookup_id(swishChecker['UPRN']),
        )

    def lookup_id(self, uprn):
        checkerResult = requests.get(
            self.APIAddress,
            params={
                "uprn": uprn,
            }
        )
        checkerData = json.loads(checkerResult.text)

        returnData = {
            'addressdata': checkerData['data'],
            'serviceable': False,
            'success': False,
            'fttp': False,
        }

        if len(checkerData['data']) != 1:
            return BroadbandResult(
                data=returnData,
            )

        returnData['success'] = True
        returnData['message'] = checkerData['data'][0]['streetUnitStatus']['code']

        if returnData['message'] == 100:
            returnData.update({
                'serviceable': True,
                'fttp': True,
                'success': True,
            })

        return returnData
