import requests
import json
from .resultclass import BroadbandResult
from .addressmatch import UKBroadbandAddressMatcher

class HeyBroadbandChecker:
    def __init__(
        self,
        checkerAddress="https://heybroadband.co.uk/api",
    ):
        self.checkerAddress = checkerAddress


    def query_address(self, postCode, houseNumber, strictAddress=True):
        address_list = requests.get(
            f'{self.checkerAddress}/uprn-by-postcode',
            json={
                "postcode": postCode,
            },
        )

        address_list = json.loads(address_list.text)
        if (len(address_list) == 0):
            returnResult = BroadbandResult(
                data={
                    "addressData": False,
                    'serviceable': False,
                    'success': True,
                    'fttp': False,
                    'planned': False,
                },
            )
            return returnResult

        premiseCheckArray = []
        for thisAddress in address_list:
            premiseCheckArray.append({
                "addressLine": thisAddress['address'],
                "returnValue": thisAddress,
            })

        premise, strictMatched = UKBroadbandAddressMatcher(
            houseNumber,
            postCode,
            premiseCheckArray
        )

        if not strictMatched:
            if strictAddress:
                returnResult = BroadbandResult(
                    data={
                        "addressData": False,
                        'serviceable': False,
                        'success': False,
                        'fttp': False,
                    },
                )
                return returnResult
            else:
                premise['looseMatch'] = True

        returnData = {
            "addressData": premise,
            "message": premise['coverage'],
            'serviceable': False,
            'planned': False,
            'success': False,
            'fttp': False,
        }

        if premise['coverage'] in ["PASSED", "DESIGN"]:
            returnData.update({
                'planned': True,
                'success': True,
            })
        elif premise['coverage'] in ["PASSSERV", "CUSTOMER"]:
            returnData.update({
                'serviceable': True,
                'planned': True,
                'success': True,
                'fttp': True,
            })
        elif premise['coverage'] == "NOTPASSED":
            returnData.update({
                'success': True,
            })

        returnResult = BroadbandResult(
            data=returnData,
        )
        returnResult.fttp = returnData['serviceable']

        return returnResult
