import requests
import json
from .resultclass import BroadbandResult
from .addressmatch import UKBroadbandAddressMatcher

class JFChecker:
    def __init__(
        self,
        apiAddress="https://jurassic-fibre.com/wp-json/integrations/v1",
    ):
        self.apiAddress = apiAddress


    def query_address(self, postCode, houseNumber, strictAddress=True):
        address_list = requests.post(
            f'{self.apiAddress}/postcode',
            data={"postcode": postCode}
        )
        premiseCheckList = json.loads(json.loads(address_list.text)['response'])
        premiseCheckArray = []
        for thisAddress in premiseCheckList:
            premiseCheckArray.append({
                "addressLine": thisAddress['full_address'],
                "returnValue": thisAddress,
            })

        premise, strictMatched = UKBroadbandAddressMatcher(
            houseNumber,
            postCode,
            premiseCheckArray
        )
        if not strictMatched:
            if strictAddress:
                returnResult = BroadbandResult(
                    data={
                        "addressData": False,
                        'serviceable': False,
                        'success': False,
                        'fttp': False,
                    },
                )
                return returnResult
            else:
                premise['looseMatch'] = True

        serviceability = requests.post(
            f"{self.apiAddress}/status",
            data={"UPRN": premise['uprn']}
        )
        message = json.loads(serviceability.text)

        returnData = {
            "addressData": premise,
            "message": message,
            'serviceable': False,
            'planned': False,
            'success': False,
        }

        if returnData['message']['redirect'] == 'https://jurassic-fibre.com/we-are-coming-to-you-soon/':
            returnData.update({
                'planned': True,
                'success': True,
            })
        elif returnData['message']['redirect'] == 'https://jurassic-fibre.com/we-hope-to-be-with-you-soon/':
            returnData.update({
                'success': True,
            })
        elif returnData['message']['redirect'] == 'https://jurassic-fibre.com/youre-ready-to-go-ultrafast/':
            returnData.update({
                'serviceable': True,
                'planned': True,
                'success': True,
            })

        returnResult = BroadbandResult(
            data=returnData,
        )
        returnResult.fttp = returnData['serviceable']

        return returnResult


    @staticmethod
    def determine_premise(struct, number, strictAddress):
        data = json.loads(struct)
        addresses = json.loads(data['response'])
        number = number.lower()
        for premise in addresses:
            if premise['building'] == number:
                return premise
        if strictAddress:
            return dict()

        addresses[0]['looseMatch'] = True
        return addresses[0]
