import requests
import json
from .resultclass import BroadbandResult
from .addressmatch import UKBroadbandAddressMatcher
from urllib.parse import unquote

class PineMediaChecker:
    def __init__(
        self,
        checkerAddress="https://pinemedia.net",
    ):
        self.checkerAddress = checkerAddress
        self.session = requests.Session()


    def query_address(self, postCode, houseNumber, strictAddress=True):
        postCode = ''.join(ch for ch in postCode if ch.isalnum())
        checker = self.session.get(
            f'{self.checkerAddress}/search_postal_code',
            params={
                "post_code": postCode,
            }
        )

        premiseCheckList = json.loads(checker.text)['addresses']
        premiseCheckArray = []
        for thisAddress in premiseCheckList:
            premiseCheckArray.append({
                "addressLine": thisAddress['houseNumber'],
                "returnValue": thisAddress,
            })

        premise, strictMatched = UKBroadbandAddressMatcher(
            houseNumber,
            postCode,
            premiseCheckArray
        )

        if not strictMatched:
            if strictAddress:
                returnResult = BroadbandResult(
                    data={
                        "addressData": False,
                        'serviceable': False,
                        'success': False,
                        'fttp': False,
                    },
                )
                return returnResult
            else:
                premise['looseMatch'] = True
                premise['address'] = \
                    f"{premise['buildingName']}{premise['houseNumber']}," \
                    f" {premise['streetName']}"

        idLookup = self.lookup_id(
            uprn=premise['uprn'],
        )

        idLookup['addressData'] = premise
        return BroadbandResult(data=idLookup)


    def lookup_id(self, uprn):
        sessionCookies = self.session.cookies.get_dict()
        if "XSRF-TOKEN" not in sessionCookies:
            # TODO: Can we make this up? It'd be better to avoid a request here.
            self.session.get(self.checkerAddress)
            sessionCookies = self.session.cookies.get_dict()

        infrastructureData = self.session.post(
            f"{self.checkerAddress}/create-quote",
            json={
                "address": {
                    "uprn": uprn,
                    "listOfTechnology": {},
                }
            },
            headers={
                'x-xsrf-token': unquote(sessionCookies['XSRF-TOKEN']),
            },
        )
        infrastructureData = json.loads(infrastructureData.text)

        returnData = {
            "addressData": {
                "uprn": uprn,
            },
            "message": infrastructureData,
            'serviceable': False,
            'success': True,
        }

        if infrastructureData['infrastructure_id']:
            returnData['serviceable'] = True
            returnData['success'] = True

        returnData['fttp'] = returnData['serviceable']

        return returnData
