import requests
import json
from .resultclass import BroadbandResult
from bs4 import BeautifulSoup

class SwichFibreChecker:
    def __init__(
        self,
        APIAddress="https://portal.swishfibre.com",
        OSAPI="https://api.ordnancesurvey.co.uk/",
        OSAPIKey="1WH9MAyIiPSCncSDFIO5GabIl7PD4ouE",
    ):
        self.APIAddress = APIAddress
        self.OSAPI = OSAPI
        self.OSAPIKey = OSAPIKey

    def match_uprn(self, postCode, houseNumber):
        postCode = ''.join(ch for ch in postCode if ch.isalnum())

        OSLookup = requests.get(
            f"{self.OSAPI}/places/v1/addresses/match",
            params={
                "format": "json",
                "maxresults": "1",
                "offset": "0",
                "query": f"{houseNumber}, {postCode}",
                "key": self.OSAPIKey,
            }
        )
        addressData = json.loads(OSLookup.text)

        if len(addressData['results']) == 1 and \
            addressData['results'][0]['DPA']['MATCH'] > 0.7:
            return addressData['results'][0]['DPA']


    def query_address(self, postCode, houseNumber, strictAddress=True):
        addressMatch = self.match_uprn(postCode, houseNumber)

        session = requests.Session()
        session.get(self.APIAddress)

        checkerData = session.get(
            f'{self.APIAddress}/SearchAddress/SaveDataAndRedirect',
            params={
                "uprn": addressMatch['UPRN'],
                "residentialStatus": "HOME",
            },
        )
        checkerData = json.loads(checkerData.text)

        returnData = {
            'addressdata': addressMatch,
            'serviceable': False,
            'planned': False,
            'success': False,
            'message': checkerData,
        }

        if checkerData['data'] == "/RegisterOfInterest":
            returnData['success'] = True
        elif checkerData['data'] == "/SelectProduct":
            houseLookup = session.get(
                f"{self.APIAddress}/SelectProduct"
            )

            soup = BeautifulSoup(houseLookup.text, 'html.parser')
            message = soup.find('h2').text.strip()

            returnData['message']['message'] = message

            if "pre-order" in message:
                returnData.update({
                    'planned': True,
                    'success': True,
                })
            elif "you can get Swish" in message:
                returnData.update({
                    'serviceable': True,
                    'success': True,
                })

        returnResult = BroadbandResult(
            data=returnData,
        )
        returnResult.fttp = returnData['serviceable']

        return returnResult
