import requests
import json
from .resultclass import BroadbandResult

class ToobChecker:
    def __init__(
        self,
        APIAddress="https://www.toob.co.uk/api-interface/api/postcode/",
    ):
        self.APIAddress = APIAddress

    def query_address(self, postCode, houseNumber, strictAddress=True):
        currentPage = 1
        totalPages = 1
        addressList = []
        lastStatus = 200

        while totalPages >= currentPage:
            pageContents = requests.post(
                self.APIAddress,
                data={
                    "postcode": postCode,
                    "pageIndex": currentPage,
                },
            )
            currentPage = currentPage + 1
            pageData = json.loads(pageContents.text)
            totalPages = pageData['total_pages']
            addressList = addressList + pageData['formatted_addresses']
            lastStatus = pageData['statusCode']

        returnData = {
            "addressData": False,
            'serviceable': False,
            'success': False,
            'planned': False,
            'fttp': False,
        }

        if len(addressList) > 0 :
            premise = self.determine_premise(addressList, houseNumber, strictAddress)
            returnData['addressData'] = premise

            if premise['connection_ready_status'] == 'is_orderable':
                returnData.update({
                    'success': True,
                    'serviceable': True,
                    'fttp': True,
                })
            elif premise['connection_ready_status'] == 'roi_with_contact_promise':
              returnData.update({
                    'success': True,
                    'planned': True,
                })
        elif lastStatus == 200:
            returnData.update({
                'success': True,
            })

        returnResult = BroadbandResult(
            data=returnData,
        )
        returnResult.fttp = returnData['serviceable']

        return returnResult


    # This is unreliable, I have seen like "34 B" for people who have 34B, we
    # should add some script to work this out, the same logic can be used for
    # cityfibre.
    @staticmethod
    def determine_premise(data, number, strictAddress):
        number = f"{number}".lower()
        for premise in data:
            if premise['street_number'] == number:
                return premise
        if strictAddress:
            return dict()

        data[0]['looseMatch'] = True
        return data[0]
