import requests
import json
from .resultclass import BroadbandResult

class TrooliChecker:
    def __init__(
        self,
        APIAddress="https://www.trooli.com/wp-content/themes/PRODUCTION_v2/ajax/postcode-lookup.php",
    ):
        self.APIAddress = APIAddress

    def query_address(self, postCode, houseNumber, strictAddress=True):
        address_list = requests.get(
            self.APIAddress,
            params={
                "postcode": postCode,
            },
        )
        premiseList = json.loads(address_list.text)

        returnData = {
            "addressData": False,
            'serviceable': False,
            'success': False,
            'fttp': False,
        }

        if premiseList['error']:
            returnData.update({
                'success': True,
            })
        else:
            premise = self.determine_premise(premiseList['addresses'], houseNumber, strictAddress)
            if len(premise) > 0:
                returnData.update({
                    'addressData': premise,
                })
            if len(premise) > 0 and premise['available']:
                returnData.update({
                    'success': True,
                    'serviceable': True,
                    'fttp': True,
                })

        returnResult = BroadbandResult(
            data=returnData,
        )
        returnResult.fttp = returnData['serviceable']

        return returnResult


    # This is unreliable, I have seen like "34 B" for people who have 34B, we
    # should add some script to work this out, the same logic can be used for
    # cityfibre.
    @staticmethod
    def determine_premise(data, number, strictAddress):
        number = number.lower()
        for premise in data:
            if premise['address'].startswith(f'{number} '):
                return premise
            elif premise['address'].startswith(f'{number}, '):
                return premise
        if strictAddress:
            return dict()

        data[0]['looseMatch'] = True
        return data[0]
