import requests
import json
from bs4 import BeautifulSoup
from .resultclass import BroadbandResult

class TSChecker:
    def __init__(
        self,
        siteAddress="https://www.truespeed.com",
    ):
        self.siteAddress = siteAddress


    def query_address(self, postCode, houseNumber, strictAddress=True):
        address_list = requests.post(
            f'{self.siteAddress}/broadband/addresses',
            data={"postcode": postCode}
        )
        premise = self.determine_premise(address_list.text, houseNumber, strictAddress)

        if len(premise) == 0:
            returnResult = BroadbandResult(
                data={
                    "addressData": False,
                    'serviceable': False,
                    'success': False,
                    'fttp': False,
                },
            )
            return returnResult

        serviceability = requests.post(
            premise['url'],
        )
        soup = BeautifulSoup(serviceability.text, 'html.parser')
        message = soup.find('h2').text

        returnData = {
            "addressData": premise,
            "message": message,
            'serviceable': False,
            'planned': False,
            'success': False,
        }

        if returnData['message'].startswith("We're building into your area!"):
            returnData.update({
                'planned': True,
                'success': True,
            })
        elif returnData['message'].startswith("WE'RE LOOKING AT YOUR AREA"):
            returnData.update({
                'success': True,
            })
        elif returnData['message'].startswith("We're live in your area!"):
            returnData.update({
                'serviceable': True,
                'planned': True,
                'success': True,
            })

        returnResult = BroadbandResult(
            data=returnData,
        )
        returnResult.fttp = returnData['serviceable']

        return returnResult


    # This is unreliable, I have seen like "34 B" for people who have 34B, we
    # should add some script to work this out, the same logic can be used for
    # cityfibre.
    @staticmethod
    def determine_premise(struct, number, strictAddress):
        data = json.loads(struct)
        number = f"{number}".lower()
        for premise in data['addresses']:
            if premise['address'].startswith(f'{number} '):
                return premise
            elif premise['address'].startswith(f'{number}, '):
                return premise
        if strictAddress:
            return dict()

        data['addresses'][0]['looseMatch'] = True
        return data['addresses'][0]
