import requests
import json
from .resultclass import BroadbandResult
from .addressmatch import UKBroadbandAddressMatcher

class WessexInternetChecker:
    def __init__(
        self,
        APIAddress="https://www.wessexinternet.com/umbraco/api",
    ):
        self.APIAddress = APIAddress


    def query_address(self, postCode, houseNumber, strictAddress=True):
        postCode = ''.join(ch for ch in postCode if ch.isalnum())
        address_list = requests.post(
            f'{self.APIAddress}/AddressLookup/ContainerSearch',
            data={"q": f"GB|AB|ENG|{postCode[:-3]}_{postCode[-3:]}"},
        )

        premiseCheckList = json.loads(address_list.text)
        premiseCheckArray = []
        for thisAddress in premiseCheckList:
            premiseCheckArray.append({
                "addressLine": thisAddress['Text'],
                "returnValue": thisAddress,
            })

        if len(premiseCheckList) > 0:
            premise, strictMatched = UKBroadbandAddressMatcher(
                houseNumber,
                postCode,
                premiseCheckArray
            )
        else:
            returnResult = BroadbandResult(
                data={
                    "addressData": False,
                    'serviceable': False,
                    'success': True,
                    'fttp': False,
                    'planned': False,
                },
            )
            return returnResult

        uprn = premise['Id'].split('|')[-1]
        uprn = ''.join(x for x in uprn if x.isdigit())

        serviceabilityData = requests.get(
            f"{self.APIAddress}/salesforce/uprndata",
            params={"uprn": f"{uprn}"}
        )
        serviceabilityData = json.loads(serviceabilityData.text)

        if not strictMatched:
            if strictAddress:
                returnResult = BroadbandResult(
                    data={
                        "addressData": False,
                        'serviceable': False,
                        'success': False,
                        'fttp': False,
                    },
                )
                return returnResult
            else:
                premise['looseMatch'] = True

        '''
        If it's the first time an address is being queries, there will not be
        much in serviceabilityData until the next check (Narrative and Uprn are
        both missing)
        '''
        message = False
        if "Narrative" in serviceabilityData:
            message = serviceabilityData['Narrative']['Name']

        returnData = {
            "addressData": premise,
            "message": message,
            'serviceable': False,
            'planned': False,
            'success': False,
            'fttp': False,
        }

        if "Uprn" not in serviceabilityData:
            returnData.update({
                'success': True,
            })
        elif serviceabilityData['Uprn']['FibreStatus'] == "Fully Installed":
            returnData.update({
                'serviceable': True,
                'planned': True,
                'success': True,
                'fttp': True,
            })
        elif serviceabilityData['Uprn']['CommunityProjectId']:
            returnData.update({
                'planned': True,
                'success': True,
            })
        else:
            returnData.update({
                'success': True,
            })

        returnResult = BroadbandResult(
            data=returnData,
        )
        returnResult.fttp = returnData['serviceable']

        return returnResult
