import requests
import json
from .resultclass import BroadbandResult
from .addressmatch import UKBroadbandAddressMatcher

class YouFibreChecker:
    def __init__(
        self,
        APIAddress="https://api.prod.youfibre.com/CrmModule/v1.0",
        APIAuth="eyJhbGciOiJIUzI1NiIsInR5cCI6IkpXVCJ9.eyJpZCI6IjNhMGI0NjYyLTUwYjktNDJjZS04N2YwLTE3OWJmZWUzNGMzNCIsImlhdCI6MTYxMDMxNTk3M30.ISuhpfhg-5QhplEU8DYp-a3ML9sd3QUHziJEFdYXwMs"
    ):
        self.APIAddress = APIAddress
        self.APIAuth = APIAuth


    def query_address(self, postCode, houseNumber, strictAddress=True):
        postCode = ''.join(ch for ch in postCode if ch.isalnum())

        addressList = requests.get(
            f"{self.APIAddress}/db/Premises/search",
            params={
                "terms": postCode,
                "fields": "properties.PostalCode,properties.PostalCodeNoSpace",
                "schemas": "bd52a770-0aa4-4379-9751-119123cfe305",
                "page": 0,
                "size": 1000,
            },
            headers={
                "authorization": f"Bearer {self.APIAuth}",
            },
        )
        addressList = json.loads(addressList.text)['data']

        premiseCheckArray = []
        for thisAddress in addressList:
            premiseCheckArray.append({
                "addressLine": thisAddress['title'],
                "returnValue": thisAddress,
            })

        premise, strictMatched = UKBroadbandAddressMatcher(
            houseNumber,
            postCode,
            premiseCheckArray
        )

        if not strictMatched:
            if strictAddress:
                returnResult = BroadbandResult(
                    data={
                        "addressData": False,
                        'serviceable': False,
                        'success': False,
                        'fttp': False,
                    },
                )
                return returnResult
            else:
                premise['looseMatch'] = True
                premise['address'] = premise['title']

        idLookup = self.lookup_id(
            udprn=premise['properties']['UDPRN'],
        )
        idLookup['addressdata'] = premise

        return BroadbandResult(
            data=idLookup,
        )


    def lookup_id(self, udprn):
        checkerResult = requests.get(
            f"{self.APIAddress}/premises/{udprn}/0",
            headers={
                "authorization": f"Bearer {self.APIAuth}",
            }
        )
        checkerData = json.loads(checkerResult.text)

        returnData = {
            'addressdata': checkerData['data'],
            'serviceable': False,
            'success': False,
            'fttp': False,
            'planned': False,
        }

        returnData['success'] = True
        returnData['message'] = checkerData['data']['status']

        if returnData['message'] == "order":
            returnData.update({
                'serviceable': True,
                'fttp': True,
                'success': True,
            })
        elif returnData['message'] == "pre_order" or \
            returnData['message'] == "register_interest_plus":
            returnData.update({
                'planned': True,
                'success': True,
            })
        returnData['fttp'] = returnData['serviceable']

        return returnData
