import requests
import json
from .resultclass import BroadbandResult
from bs4 import BeautifulSoup
from urllib.parse import urlencode

class ZzoommChecker:
    def __init__(
        self,
        postcodeAPI="https://zzoomm.com/wp-json/zzoomm/postcoder/v1/search",
        queryAPI="https://zzoomm.com/wp-admin/admin-post.php",
    ):
        self.postcodeAPI = postcodeAPI
        self.queryAPI = queryAPI

    def query_address(self, postCode, houseNumber, strictAddress=True):
        address_list = requests.post(
            self.postcodeAPI,
            data=f"address={postCode}",
            headers={
                'Content-type': 'application/x-www-form-urlencoded'
            },
        )

        premiseList = json.loads(address_list.text)
        if len(premiseList['data']) == 0:
            return BroadbandResult(
                data={
                    'addressData': False,
                    'serviceable': False,
                    'success': False,
                    'fttp': False,
                },
            )

        premise = self.determine_premise(premiseList['data'], houseNumber, strictAddress)

        query = {
            "address_line_1": premise['address1'],
            "address_line_2": "",
            "city": premise['posttown'],
            "postcode": premise['postcode'],
            "uprn": premise['uprn'],
            "employee": "",
            "action": "zz_coverage",
            "product_line": "residential",
        }

        queryData = requests.post(
            self.queryAPI,
            data=urlencode(query),
            headers={
                'Content-type': 'application/x-www-form-urlencoded'
            },
        )
        soup = BeautifulSoup(queryData.text, 'html.parser')
        resultHeader = soup.find('h1').text.strip()

        premise['address'] = premise['summaryline']
        returnData = {
            'addressData': premise,
            'message': resultHeader,
            'serviceable': False,
            'success': False,
            'fttp': False,
            'planned': False,
        }

        if resultHeader == "Great news – you can place a home order today!" or \
            resultHeader == "This address is already Zzoomming!":
            returnData.update({
                'serviceable': True,
                'success': True,
                'fttp': True,
            })
        elif resultHeader == "Sorry but you're not in our current build plan." or \
            resultHeader == "Sorry, you're not in our current build plan.":
            returnData.update({
                'success': True,
            })
        elif resultHeader == "Coming to your town soon." or \
            resultHeader == "Coming to your town later this year":
            returnData.update({
            'success': True,
            'planned': True,
        })

        returnResult = BroadbandResult(
            data=returnData,
        )
        returnResult.fttp = returnData['serviceable']

        return returnResult


    # This is unreliable, I have seen like "34 B" for people who have 34B, we
    # should add some script to work this out, the same logic can be used for
    # cityfibre.
    @staticmethod
    def determine_premise(data, number, strictAddress):
        number = number.lower()
        for premise in data:
            if premise['summaryline'].startswith(f'{number} '):
                return premise
            elif premise['summaryline'].startswith(f'{number}, '):
                return premise
        if strictAddress:
            return dict()

        data[0]['looseMatch'] = True
        return data[0]
